@@ -27,6 +27,7 @@
  """
 
 import os, sys
+import copy
 import logging
 import logging.handlers
 
@@ -59,13 +60,27 @@ class StreamFilter(logging.Filter):
     """Filter out lines that originated on the output"""
     def filter(self, record):
         source = getattr(record, "source", "")
-        return bool(source != "stream")
+        return source != "stream"
+
+# Clamp log messages to a reasonable size to avoid giant lines
+MAX_LOG_MESSAGE_LENGTH = 2048
+
+
+class TruncatingFormatter(logging.Formatter):
+    """Formatter that trims overly long log messages."""
+    def format(self, record):
+        message = record.getMessage()
+        if len(message) > MAX_LOG_MESSAGE_LENGTH:
+            record = copy.copy(record)
+            record.msg = message[:MAX_LOG_MESSAGE_LENGTH] + "... [truncated]"
+            record.args = None
+        return super().format(record)
 
 
 # Set up log formatters
 template = '%(levelname)s %(module)s: %(message)s'
-console_formatter = logging.Formatter(template)
-file_formatter = logging.Formatter('%(asctime)s ' + template, datefmt='%H:%M:%S')
+console_formatter = TruncatingFormatter(template)
+file_formatter = TruncatingFormatter('%(asctime)s ' + template, datefmt='%H:%M:%S')
 
 # Configure root logger for minimal logging
 logging.basicConfig(level=logging.ERROR)
@@ -80,14 +95,19 @@ log.propagate = False
 #
 # Create rotating file handler
 #
-fh = logging.handlers.RotatingFileHandler(
-         os.path.join(info.USER_PATH, 'openshot-qt.log'),
-         encoding="utf-8",
-         maxBytes=25*1024*1024, backupCount=3)
-fh.setLevel(info.LOG_LEVEL_FILE)
-fh.setFormatter(file_formatter)
-
-log.addHandler(fh)
+if os.path.exists(info.USER_PATH):
+    fh = logging.handlers.RotatingFileHandler(
+             os.path.join(info.USER_PATH, 'openshot-qt.log'),
+             encoding="utf-8",
+             maxBytes=25*1024*1024, backupCount=3)
+    fh.setLevel(info.LOG_LEVEL_FILE)
+    fh.setFormatter(file_formatter)
+    log.addHandler(fh)
+else:
+    class DummyHandler:
+        def setLevel(self, level):
+            return True
+    fh = DummyHandler()
 
 #
 # Create typical stream handler which logs to stderr
