@@ -42,6 +42,7 @@ from classes.logger import log
 from classes.updates import UpdateInterface
 from classes.assets import get_assets_path
 from windows.views.find_file import find_missing_file
+from classes.convert_framerate import change_profile
 
 from .keyframe_scaler import KeyframeScaler
 
@@ -311,6 +312,7 @@ class ProjectDataStore(JsonDataStore, UpdateInterface):
         # Loop through legacy profiles
         LEGACY_PROFILE_PATH = os.path.join(info.PROFILES_PATH, "legacy")
         legacy_profile = None
+        legacy_profile_match = None  # Find the equivalent match of this legacy (if any)
         for legacy_filename in os.listdir(LEGACY_PROFILE_PATH):
             legacy_profile_path = os.path.join(LEGACY_PROFILE_PATH, legacy_filename)
             try:
@@ -340,13 +342,17 @@ class ProjectDataStore(JsonDataStore, UpdateInterface):
                         break
                     if legacy_profile and legacy_profile.Key() == temp_profile.Key():
                         # Switch from legacy profile to new profile
-                        profile = self.apply_profile(temp_profile)
-                        break
+                        legacy_profile_match = temp_profile
 
                 except RuntimeError as e:
                     # This exception occurs when there's a problem parsing the Profile file - display a message and continue
                     log.error("Failed to parse file '%s' as a profile: %s" % (profile_path, e))
 
+        # Upgrade a legacy profile (if needed). Sometimes legacy profiles do match a new profile description, so
+        # only upgrade if we have not already found a profile matching the description
+        if not profile and legacy_profile_match:
+            profile = self.apply_profile(legacy_profile_match)
+
         return profile
 
     def apply_profile(self, profile):
@@ -360,6 +366,10 @@ class ProjectDataStore(JsonDataStore, UpdateInterface):
         self._data["fps"] = {"num": profile.info.fps.num, "den": profile.info.fps.den}
         self._data["display_ratio"] = {"num": profile.info.display_ratio.num, "den": profile.info.display_ratio.den}
         self._data["pixel_ratio"] = {"num": profile.info.pixel_ratio.num, "den": profile.info.pixel_ratio.den}
+
+        # Convert all position, start, and end trims to profile FPS precision (if any)
+        change_profile(self._data["clips"] + self._data["effects"] + self._data["markers"], profile)
+
         return profile
 
     def load(self, file_path, clear_thumbnails=True):
@@ -409,6 +419,7 @@ class ProjectDataStore(JsonDataStore, UpdateInterface):
                 info.TITLE_PATH = os.path.join(get_assets_path(self.current_filepath), "title")
                 info.BLENDER_PATH = os.path.join(get_assets_path(self.current_filepath), "blender")
                 info.PROTOBUF_DATA_PATH = os.path.join(get_assets_path(self.current_filepath), "protobuf_data")
+                info.CLIPBOARD_PATH = os.path.join(get_assets_path(self.current_filepath), "clipboard")
 
             # Clear needs save flag
             self.has_unsaved_changes = False
@@ -445,13 +456,10 @@ class ProjectDataStore(JsonDataStore, UpdateInterface):
     def rescale_keyframes(self, scale_factor):
         """Adjust all keyframe coordinates from previous FPS to new FPS (using a scale factor)
            and return scaled project data without modifing the current project."""
-        #
         log.info('Scale all keyframes by a factor of %s', scale_factor)
-        # Create a scaler instance
+        # Create a scaler instance, and scale all key-frames
         scaler = KeyframeScaler(factor=scale_factor)
-        # Create copy of active project data and scale
-        scaled = scaler(json.loads(json.dumps(self._data)))
-        return scaled
+        scaler(self._data)
 
     def read_legacy_project_file(self, file_path):
         """Attempt to read a legacy version 1.x openshot project file"""
@@ -771,10 +779,7 @@ class ProjectDataStore(JsonDataStore, UpdateInterface):
                         self.is_keyframe_valid(crop_height, 1.0),
                        ]):
                     # Apply crop effect to clip (which wasn't available in 2.5.x)
-                    log.info(
-                        "Migrating OpenShot 2.5 crop properties for clip %s",
-                        clip.get("id", "<unknown>")
-                    )
+                    log.info("Migrating OpenShot 2.5 crop properties for clip %s", clip.get("id", "<unknown>"))
                     from json import loads as jl
                     effect = openshot.EffectInfo().CreateEffect("Crop")
                     effect.Id(get_app().project.generate_id())
@@ -796,6 +801,57 @@ class ProjectDataStore(JsonDataStore, UpdateInterface):
                     # Append effect JSON to clip
                     clip["effects"].append(effect_json)
 
+
+        elif openshot_version <= "3.1.1":
+
+            # Reverse alpha value for Tracker & Object Detector tracked boxes
+            log.debug("Scanning OpenShot project for legacy TrackedObjectBBox (background_alpha, stroke_alpha)")
+
+            for clip in self._data.get("clips", []):
+                for effect in clip.get("effects", []):
+                    if effect.get("name") in ["Tracker", "Object Detector"]:
+
+                        # Update display_box_text
+                        if "display_box_text" in effect:
+                            log.info("Migrating legacy Object Detector display_box_text property "
+                                     "for clip %s", clip.get("id", "<unknown>"))
+                            display_box_text_points = effect.get("display_box_text", {}).get("Points", [])
+                            for point in display_box_text_points:
+                                if "co" in point:
+                                    display_box_text = point.get("co", {}).get("Y", 1.0)
+                                    point["co"]["Y"] = 1.0 - display_box_text
+                            if not display_box_text_points:
+                                # Default to text visible
+                                display_box_text_points.append(json.loads(openshot.Point(1.0).Json()))
+
+                        # Update tracked objects
+                        objects = effect.get("objects", {})
+                        for tracked_key, tracked_data in objects.items():
+                            log.info("Migrating legacy TrackedObjectBBox alpha properties "
+                                     "for clip %s and tracked object: %s", clip.get("id", "<unknown>"), tracked_key)
+
+                            # Update Child Clip ID to Parent property (if any)
+                            child_clip_id = tracked_data.get("child_clip_id")
+                            if child_clip_id:
+                                for child_clip in self._data.get("clips", []):
+                                    if child_clip.get("id") == child_clip_id:
+                                        log.info(f"Migrating child_clip_id {child_clip_id} to parent property for tracked object {tracked_key}")
+                                        child_clip["parentObjectId"] = tracked_key
+
+                            # Update background_alpha points directly
+                            background_alpha_points = tracked_data.get("background_alpha", {}).get("Points", [])
+                            for point in background_alpha_points:
+                                if "co" in point:
+                                    background_alpha = point.get("co", {}).get("Y", 1.0)
+                                    point["co"]["Y"] = 1.0 - background_alpha
+
+                            # Update stroke_alpha points directly
+                            stroke_alpha_points = tracked_data.get("stroke_alpha", {}).get("Points", [])
+                            for point in stroke_alpha_points:
+                                if "co" in point:
+                                    stroke_alpha = point.get("co", {}).get("Y", 1.0)
+                                    point["co"]["Y"] = 1.0 - stroke_alpha
+
         # Fix default project id (if found)
         if self._data.get("id") == "T0":
             self._data["id"] = self.generate_id()
@@ -840,6 +896,7 @@ class ProjectDataStore(JsonDataStore, UpdateInterface):
             info.THUMBNAIL_PATH = os.path.join(get_assets_path(self.current_filepath), "thumbnail")
             info.TITLE_PATH = os.path.join(get_assets_path(self.current_filepath), "title")
             info.BLENDER_PATH = os.path.join(get_assets_path(self.current_filepath), "blender")
+            info.CLIPBOARD_PATH = os.path.join(get_assets_path(self.current_filepath), "clipboard")
 
             self.add_to_recent_files(file_path)
             self.has_unsaved_changes = False
@@ -853,11 +910,13 @@ class ProjectDataStore(JsonDataStore, UpdateInterface):
             target_title_path = os.path.join(asset_path, "title")
             target_blender_path = os.path.join(asset_path, "blender")
             target_protobuf_path = os.path.join(asset_path, "protobuf_data")
+            target_clipboard_path = os.path.join(asset_path, "clipboard")
 
             # Create any missing target paths
             try:
                 for target_dir in [asset_path, target_thumb_path, target_title_path,
-                                   target_blender_path, target_protobuf_path]:
+                                   target_blender_path, target_protobuf_path,
+                                   target_clipboard_path]:
                     if not os.path.exists(target_dir):
                         os.mkdir(target_dir)
             except OSError:
@@ -871,9 +930,14 @@ class ProjectDataStore(JsonDataStore, UpdateInterface):
                 info.TITLE_PATH = os.path.join(previous_asset_path, "title")
                 info.BLENDER_PATH = os.path.join(previous_asset_path, "blender")
                 info.PROTOBUF_DATA_PATH = os.path.join(previous_asset_path, "protobuf_data")
+                info.CLIPBOARD_PATH = os.path.join(previous_asset_path, "clipboard")
 
             # Track assets we copy/update
-            copied = []
+            copied_assets = {
+                "blender": set(),
+                "title": set(),
+                "clipboard": set(),
+            }
             reader_paths = {}
 
             # Copy all thumbnail files (if not found in target asset folder)
@@ -897,6 +961,14 @@ class ProjectDataStore(JsonDataStore, UpdateInterface):
                 if os.path.isdir(working_blender_path) and not os.path.exists(target_blender_filepath):
                     shutil.copytree(working_blender_path, target_blender_filepath)
 
+            # Copy all clipboard files (if not found in target asset folder)
+            if os.path.exists(info.CLIPBOARD_PATH):
+                for clipboard_path in os.listdir(info.CLIPBOARD_PATH):
+                    working_clipboard_path = os.path.join(info.CLIPBOARD_PATH, clipboard_path)
+                    target_clipboard_filepath = os.path.join(target_clipboard_path, clipboard_path)
+                    if not os.path.exists(target_clipboard_filepath):
+                        shutil.copy2(working_clipboard_path, target_clipboard_filepath)
+
             # Copy all protobuf files (if not found in target asset folder)
             for protobuf_path in os.listdir(info.PROTOBUF_DATA_PATH):
                 working_protobuf_path = os.path.join(info.PROTOBUF_DATA_PATH, protobuf_path)
@@ -918,10 +990,10 @@ class ProjectDataStore(JsonDataStore, UpdateInterface):
                     # Copy directory of blender files
                     log.info("Copying %s", path)
                     old_dir, asset_name = os.path.split(path)
-                    if os.path.isdir(old_dir) and old_dir not in copied:
+                    if os.path.isdir(old_dir) and old_dir not in copied_assets["blender"]:
                         # Copy dir into new folder
                         old_dir_name = os.path.basename(old_dir)
-                        copied.append(old_dir)
+                        copied_assets["blender"].add(old_dir)
                         log.info("Copied dir %s to %s", old_dir_name, target_blender_path)
                     new_asset_path = os.path.join(target_blender_path, old_dir_name, asset_name)
 
@@ -929,12 +1001,20 @@ class ProjectDataStore(JsonDataStore, UpdateInterface):
                     # Copy title files into assets folder
                     log.info("Copying %s", path)
                     old_dir, asset_name = os.path.split(path)
-                    if asset_name not in copied:
+                    if asset_name not in copied_assets["title"]:
                         # Copy title into assets title folder
-                        copied.append(asset_name)
+                        copied_assets["title"].add(asset_name)
                         log.info("Copied title %s to %s", asset_name, target_title_path)
                     new_asset_path = os.path.join(target_title_path, asset_name)
 
+                if info.CLIPBOARD_PATH in path:
+                    log.info("Copying %s", path)
+                    old_dir, asset_name = os.path.split(path)
+                    if asset_name not in copied_assets["clipboard"]:
+                        copied_assets["clipboard"].add(asset_name)
+                        log.info("Copied clipboard %s to %s", asset_name, target_clipboard_path)
+                    new_asset_path = os.path.join(target_clipboard_path, asset_name)
+
                 # Update path in File object to new location
                 if new_asset_path:
                     file["path"] = new_asset_path
@@ -1057,6 +1137,45 @@ class ProjectDataStore(JsonDataStore, UpdateInterface):
             action.set_old_values(old_vals)  # Save previous values to reverse this action
             self.has_unsaved_changes = True
 
+            if len(action.key) == 1 and action.key[0] in ["fps"]:
+                # FPS changed (apply profile)
+                profile_key = self._data.get("profile")
+                profile = self.get_profile(profile_key)
+                if profile:
+                    # Get current FPS (prior to changing)
+                    new_fps = self._data.get("fps")
+                    new_fps_float = float(new_fps["num"]) / float(new_fps["den"])
+                    old_fps_float = float(old_vals["num"]) / float(old_vals["den"])
+                    fps_factor = float(new_fps_float / old_fps_float)
+
+                    if fps_factor != 1.0:
+                        log.info(f"Convert {old_fps_float} FPS to {new_fps_float} FPS (profile: {profile.ShortName()})")
+                        # Snap to new FPS grid (start, end, duration)
+                        change_profile(self._data["clips"] + self._data["effects"], profile)
+
+                        # Rescale keyframes to match new FPS
+                        self.rescale_keyframes(fps_factor)
+
+                    # Update size of audio-only files
+                    for file in self._data.get("files", []):
+                        # Check for audio-only files
+                        if file.get("has_audio") and not file.get("has_video"):
+                            # Audio-only file should match the current project size and FPS
+                            file["width"] = profile.info.width
+                            file["height"] = profile.info.height
+                            file["display_ratio"]["num"] = profile.info.display_ratio.num
+                            file["display_ratio"]["den"] = profile.info.display_ratio.den
+
+                            # Change all related clips
+                            for clip in self._data.get("clips", []):
+                                if clip.get("reader", {}).get("id") == file.get("id"):
+                                    clip["reader"] = file
+
+                    # Broadcast this change out
+                    get_app().updates.load(self._data, reset_history=False)
+                else:
+                    log.warning(f"No profile found for {profile_key}")
+
         elif action.type == "delete":
             # Delete existing item
             old_vals = self._set(action.key, remove=True)
