@@ -121,6 +121,7 @@ class UpdateAction:
         self.key = update_action_dict.get("key")
         self.values = update_action_dict.get("value")
         self.old_values = update_action_dict.get("old_values")
+        self.transaction = update_action_dict.get("transaction", self.transaction)
 
         # Always remove 'history' key (if found). This prevents nested "history"
         # attributes when a project dict is loaded.
@@ -148,6 +149,7 @@ class UpdateManager:
         self.last_action = None  # The last action processed
         self.pending_action = None  # Last action not added to actionHistory list
         self.transaction_id = None  # The current transaction id to be attached to any UpdateActions created
+        self.data_version = 0  # Incremented on every dispatch to invalidate caches
 
     def load_history(self, project):
         """Load history from project"""
@@ -284,15 +286,28 @@ class UpdateManager:
     def undo(self):
         """ Undo the last UpdateAction (and notify all listeners and watchers).
             Continue until all identical transaction ids have been found. """
-        last_transaction = None
-        for last_action in reversed(self.actionHistory):
-            # Compare transaction ids
-            if last_transaction and last_transaction != last_action.transaction:
-                # Different transaction, skip
-                continue
-            else:
-                last_transaction = last_action.transaction or str(uuid.uuid4())
-                self.actionHistory.remove(last_action)
+        # Get all actions with the same transaction id as the last one, in reverse order
+        last_transaction = self.actionHistory[-1].transaction if self.actionHistory else None
+        last_transactions = [a for a in reversed(self.actionHistory) if a.transaction == last_transaction]
+        remove_selection = any(a.type == "insert" for a in last_transactions)
+
+        if remove_selection:
+            # Remove selections for any items about to be deleted
+            for action in last_transactions:
+                if action.type == "insert":
+                    object_id = action.values.get("id", None)
+                    get_app().window.removeSelection(object_id, None)
+
+            # Force property and selection timers to fire
+            get_app().window.show_property_timer.stop()
+            get_app().window.show_property_timer.timeout.emit()
+            get_app().window.selection_timer.stop()
+            get_app().window.selection_timer.timeout.emit()
+            get_app().processEvents()
+
+        # Iterate each action in this transaction
+        for index, last_action in enumerate(last_transactions):
+            self.actionHistory.remove(last_action)
 
             # Copy action
             last_action = last_action.copy()
@@ -303,6 +318,10 @@ class UpdateManager:
             # Get reverse of last action and perform it
             reverse = self.get_reverse_action(last_action)
 
+            # Ignore updates to UI on all actions except last one
+            ignore_refresh = (index != len(last_transactions) - 1)
+            get_app().window.IgnoreUpdates.emit(ignore_refresh, True)
+
             # Perform next undo action
             self.dispatch_action(reverse)
 
@@ -312,15 +331,13 @@ class UpdateManager:
     def redo(self):
         """ Redo the last UpdateAction (and notify all listeners and watchers).
             Continue until all identical transaction ids have been found. """
-        last_transaction = None
-        for next_action in reversed(self.redoHistory):
-            # Compare transaction ids
-            if last_transaction and last_transaction != next_action.transaction:
-                # Different transaction, skip
-                continue
-            else:
-                last_transaction = next_action.transaction or str(uuid.uuid4())
-                self.redoHistory.remove(next_action)
+        # Get all actions with the same transaction id as the last one, in reverse order
+        last_transaction = self.redoHistory[-1].transaction if self.redoHistory else None
+        last_transactions = [a for a in reversed(self.redoHistory) if a.transaction == last_transaction]
+
+        # Iterate through each action in this transaction
+        for index, next_action in enumerate(last_transactions):
+            self.redoHistory.remove(next_action)
 
             # Copy action
             next_action = next_action.copy()
@@ -331,6 +348,11 @@ class UpdateManager:
 
             self.actionHistory.append(next_action)
             self.pending_action = None
+
+            # Ignore updates to UI on all actions except last one
+            ignore_refresh = (index != len(last_transactions) - 1)
+            get_app().window.IgnoreUpdates.emit(ignore_refresh, True)
+
             # Perform next redo action
             self.dispatch_action(next_action)
 
@@ -338,6 +360,9 @@ class UpdateManager:
     def dispatch_action(self, action):
         """ Distribute changes to all listeners (by calling their changed() method) """
 
+        # Every dispatched action reflects a project mutation; bump the version
+        self.data_version += 1
+
         try:
             # Loop through all listeners
             for listener in self.updateListeners:
