@@ -70,27 +70,6 @@ def save_profile(definition_path, json_details):
         f1.write(formatted_json)
 
 
-def replace_preset_profile(match):
-    """Replace matched string"""
-    legacy_profile_name = match.groups(0)[0]
-    # LEGACY PROFILES
-    for profile_details in legacy_profiles.values():
-        for profile_tuple in profile_details:
-            legacy_profile = profile_tuple[0]
-            if legacy_profile_name == legacy_profile.info.description:
-                new_profile_path = os.path.join(PROFILE_PATH, legacy_profile.Key())
-                profile_obj = openshot.Profile(new_profile_path)
-                return f"\t<projectprofile>{profile_obj.info.description}</projectprofile>"
-    # NEW PROFILES (if needed)
-    for new_profile_name in sorted(os.listdir(PROFILE_PATH)):
-        new_profile_path = os.path.join(PROFILE_PATH, new_profile_name)
-        if not os.path.isdir(new_profile_path):
-            profile_obj = openshot.Profile(new_profile_path)
-            if legacy_profile_name == profile_obj.info.description:
-                return f"\t<projectprofile>{profile_obj.info.description}</projectprofile>"
-    raise Exception(f"No matching legacy profile found for {legacy_profile_name}")
-
-
 # Check for arg value
 mode = ""
 if len(sys.argv) <= 1:
@@ -235,6 +214,7 @@ if mode == "generate":
             profile.info.pixel_ratio.num = p[1].get("sar").get("num")
             profile.info.pixel_ratio.den = p[1].get("sar").get("den")
             profile.info.interlaced_frame = not p[1].get("progressive")
+            profile.info.spherical = p[0].get("spherical", False)
 
             # Format file name for new profile
             profile_abr = p[2]
@@ -286,6 +266,11 @@ if mode == "generate":
             print(f"Error: Anamorphic property is NOT needed for {profile.Key()}")
 
         # Create new profile file
+        # Check if spherical attribute should be included
+        spherical_string = ""
+        if hasattr(profile.info, "spherical") and profile.info.spherical == 1:
+            spherical_string = "\nspherical=1"
+
         profile_body = f"""description={profile.info.description}
 frame_rate_num={profile.info.fps.num}
 frame_rate_den={profile.info.fps.den}
@@ -295,24 +280,13 @@ progressive={progressive_string}
 sample_aspect_num={profile.info.pixel_ratio.num}
 sample_aspect_den={profile.info.pixel_ratio.den}
 display_aspect_num={profile.info.display_ratio.num}
-display_aspect_den={profile.info.display_ratio.den}"""
+display_aspect_den={profile.info.display_ratio.den}{spherical_string}"""
 
         # Write file
         print(f"Generating profile file: {profile_name}")
         with open(profile_path, "w") as profile_file_object:
             profile_file_object.write(profile_body)
 
-    # Migrate any related presets
-    PRESETS_PATH = os.path.join(os.path.dirname(os.path.dirname(PATH)), "presets")
-    for preset_name in os.listdir(PRESETS_PATH):
-        preset_path = os.path.join(PRESETS_PATH, preset_name)
-        print(f"Updating preset file: {preset_name}")
-        with open(preset_path, "r") as f:
-            preset_body = f.read()
-            preset_body = re.sub(PRESET_REGEX, replace_preset_profile, preset_body)
-            with open(preset_path, "w") as f1:
-                f1.write(preset_body)
-
     # Iterate through duplicate profile names (and give a unique descriptive name)
     # For now, we'll add the DAR to the end of the description
     for profile_name, keys in unique_profile_names.items():
@@ -321,7 +295,7 @@ display_aspect_den={profile.info.display_ratio.den}"""
                 profile_path = os.path.join(PROFILE_PATH, key)
                 profile = openshot.Profile(profile_path)
                 # Create unique name (since more than 2 profiles use the same name)
-                unique_profile_name = f'{profile_name} - {profile.info.width}x{profile.info.height} | {profile.info.display_ratio.num}:{profile.info.display_ratio.den}'
+                unique_profile_name = f'{profile_name} | {profile.info.display_ratio.num}:{profile.info.display_ratio.den}'
                 print(f'Updating name for uniqueness: {unique_profile_name} in profile: {profile.Key()}')
 
                 # Write file with description updated for uniqueness
@@ -347,6 +321,7 @@ if mode == "preview":
             profile.info.pixel_ratio.num = p[1].get("sar").get("num")
             profile.info.pixel_ratio.den = p[1].get("sar").get("den")
             profile.info.interlaced_frame = not p[1].get("progressive")
+            profile.info.spherical = p[0].get("spherical", False)
 
             sar = profile.info.pixel_ratio
             sar.Reduce()
@@ -453,10 +428,10 @@ if mode == "doc":
                 print("".ljust(len(preset.get('title')), "~"))
                 print()
                 print(f".. table::")
-                print(f"   :widths: 26")
+                print(f"   :widths: 30 30")
                 print(f"")
                 print(f"   =======================  ============")
-                print(f"   Attribute                Description")
+                print(f"   Preset Attribute         Description")
                 print(f"   =======================  ============")
                 print(f"   Video Format             {preset.get('videoformat').upper()}")
                 if preset.get('videocodec'):
