@@ -55,6 +55,23 @@ QWidget#tutorial {
     padding: 20px;
 }
 
+QLabel#lblTutorialText {
+    font-size: 14px;
+}
+
+QCheckBox#checkboxMetrics {
+    font-size: 14px;
+}
+
+QWidget#tutorial QPushButton#NextTip {
+    background-color: #283241;
+    font-size: 12px;
+}
+
+QWidget#tutorial QPushButton#HideTutorial {
+    font-size: 12px;
+}
+
 
 QDialog {
     background-color: #192332;
@@ -122,6 +139,9 @@ QToolBar#toolBar QToolButton {
     color: #91C3FF;
     padding-top: 10px;
     padding-bottom: 10px;
+    padding-left: 8px;
+    padding-right: 8px;
+    border: none;
 }
 
 QToolBar#toolBar QToolButton:hover {
@@ -188,7 +208,7 @@ QPushButton {
 }
 
 QPushButton:hover {
-    background-color: #283241 
+    background-color: #283241;
 }
 
 QWidget#settingsContainer {
@@ -199,6 +219,37 @@ QWidget#scrollAreaWidgetContents {
     background-color: #141923;
 }
 
+QPushButton#dock-close-button {
+    image: url({PATH}themes/cosmic/images/dock-close.svg);
+    padding: 0px;
+    padding-top: 2px;
+    padding-bottom: 2px;
+    margin: 0px;
+    margin-right: 16px;
+    width: 16px;
+    height: 16px;
+}
+QPushButton#dock-float-button {
+    image: url({PATH}themes/cosmic/images/dock-float.svg);
+    padding: 0px;
+    padding-top: 2px;
+    padding-bottom: 2px;
+    margin: 0px;
+    width: 16px;
+    height: 16px;
+}
+
+QLabel#dock-title-label {
+    color: #91C3FF;
+    font-weight: 500;
+    padding: 16px;
+}
+
+QLabel#dock-title-handle {
+    padding-left: 16px;
+    qproperty-pixmap: url({PATH}themes/cosmic/images/dock-move.svg);
+}
+
 QDockWidget {
     background-color: #141923;
     titlebar-close-icon: url({PATH}themes/cosmic/images/dock-close.svg);
@@ -208,13 +259,6 @@ QDockWidget {
     padding: 16px;
 }
 
-QDockWidget::title {
-    text-align: left;
-    margin-top: 18px;
-    margin-bottom: 18px;
-    margin-left: 16px;
-}
-
 QDockWidget QWidget {
     border: none;
 }
@@ -233,26 +277,27 @@ QDockWidget QWidget#dockTimelineContents {
     padding: 0px;
 }
 
-QDockWidget::close-button, QDockWidget::float-button {
-    icon-size: 32px;
-}
-
-QDockWidget::close-button:hover, QDockWidget::float-button:hover {
-}
-
-QDockWidget::close-button:pressed, QDockWidget::float-button:pressed {
-}
-
 QTabBar {
-    background-color: transparent;
     border: none;
+    qproperty-drawBase: 0;
+    margin: 0px;
+    padding: 0px;
 }
 
 QTabBar::tab {
+    height: 16px;
+    border: none;
     margin-left: 16px;
-    height: 32px;
+    margin-top: 16px;
+    margin-bottom: 0px;
+    padding-bottom: 0px;
     color: rgba(145, 195, 255, 0.4);
-    background-color: transparent;
+}
+
+QTabWidget#exportTabs QTabBar::tab,
+QTabWidget#tabCategories QTabBar::tab,
+QTabWidget#tabCredits QTabBar::tab{
+    margin-bottom: 10px;
 }
 
 QTabBar::tab:selected {
@@ -324,6 +369,7 @@ QComboBox {
     padding: 6px;
     padding-left: 8px;
     padding-right: 8px;
+    combobox-popup: 0;
 }
 
 QComboBox::drop-down {
@@ -397,6 +443,7 @@ QWidget#Output QTextEdit {
 
 QToolBox::tab {
     color: #91C3FF;
+    border-top: 1px solid rgba(145, 195, 255, .2);
 }
 
 QTabWidget QWidget#pageAdvancedOptions, QWidget#pageProfile, QWidget#pageImageSequenceSettings, QWidget#pageVideoSettings, QWidget#pageAudioSettings {
@@ -426,13 +473,6 @@ QWidget#cutting QPushButton#btnAddClip:disabled {
     color: #666666;
 }
 
-QWidget#aboutDialog QWidget#txtversion {
-    background-color: #141923;
-    padding-top: 10px;
-    padding-bottom: 10px;
-    border-radius: 4px;
-}
-
 .property_value {
     foreground-color: #0078FF;
     background-color: #283241;
@@ -454,6 +494,10 @@ QMessageBox QPushButton[text="&{_('Yes')}"] {{
     background-color: #0078FF;
     color: #FFFFFF;
 }}
+
+QMessageBox QPushButton[text="&{_('Cancel')}"] {{
+    qproperty-icon: none;
+}}
         """ + self.style_sheet.replace("{PATH}", f"{path_unix_slashes}/")
 
     def apply_theme(self):
@@ -500,7 +544,8 @@ QMessageBox QPushButton[text="&{_('Yes')}"] {{
             {"action": self.app.window.actionProfile, "icon": "themes/cosmic/images/tool-profile.svg", "style": Qt.ToolButtonTextBesideIcon},
             {"expand": True},
             {"action": self.app.window.actionSave, "icon": "themes/cosmic/images/tool-save-project.svg", "style": Qt.ToolButtonTextBesideIcon},
-            {"action": self.app.window.actionExportVideo, "icon": "themes/cosmic/images/tool-export.svg", "style": Qt.ToolButtonTextBesideIcon, "stylesheet": "QToolButton {  background-color: #0078FF; color: #FFFFFF; }"},
+            {"action": self.app.window.actionExportVideo, "icon": "themes/cosmic/images/tool-export.svg",
+             "style": Qt.ToolButtonTextBesideIcon, "stylesheet": "QToolButton { background-color: #0078FF; color: #FFFFFF; border: none; } QToolButton:hover, QToolButton:pressed { background-color: #006EE6; }"},
             {"action": self.app.window.actionUpdate, "icon": "themes/cosmic/images/warning.svg", "visible": False, "style": Qt.ToolButtonTextBesideIcon, "stylesheet": "QToolButton {  background-color: #141923; color: #FABE0A; }"}
         ]
         self.set_toolbar_buttons(self.app.window.toolBar, icon_size=20, settings=toolbar_buttons)
@@ -511,6 +556,7 @@ QMessageBox QPushButton[text="&{_('Yes')}"] {{
             {"action": self.app.window.actionUndo, "icon": "themes/cosmic/images/tool-undo.svg", "style": Qt.ToolButtonIconOnly, "stylesheet": "QToolButton { margin-right: 0px; border-bottom-right-radius: 0px; border-top-right-radius: 0px; }"},
             {"action": self.app.window.actionRedo, "icon": "themes/cosmic/images/tool-redo.svg", "style": Qt.ToolButtonIconOnly, "stylesheet": "QToolButton { margin-left: 0px; border-bottom-left-radius: 0px; border-top-left-radius: 0px; }"},
             {"action": self.app.window.actionSnappingTool, "icon": "themes/cosmic/images/tool-snapping.svg", "style": Qt.ToolButtonIconOnly, "stylesheet": "QToolButton { margin-right: 0px; border-bottom-right-radius: 0px; border-top-right-radius: 0px; }"},
+            {"action": self.app.window.actionTimingTool, "icon": "themes/cosmic/images/tool-timing.svg", "style": Qt.ToolButtonIconOnly, "stylesheet": "QToolButton { margin-left: 0px; margin-right: 0px; border-bottom-left-radius: 0px; border-top-left-radius: 0px; border-bottom-right-radius: 0px; border-top-right-radius: 0px; }"},
             {"action": self.app.window.actionRazorTool, "icon": "themes/cosmic/images/tool-razor.svg", "style": Qt.ToolButtonIconOnly, "stylesheet": "QToolButton { margin-left: 0px; border-bottom-left-radius: 0px; border-top-left-radius: 0px; }"},
             {"action": self.app.window.actionAddMarker, "icon": "themes/cosmic/images/tool-add-marker.svg", "style": Qt.ToolButtonTextBesideIcon, "stylesheet": "QToolButton { margin-right: 0px; border-bottom-right-radius: 0px; border-top-right-radius: 0px; }"},
             {"action": self.app.window.actionPreviousMarker, "icon": "themes/cosmic/images/tool-prev-marker.svg", "style": Qt.ToolButtonIconOnly, "stylesheet": "QToolButton { margin-left: 0px; border-bottom-left-radius: 0px; border-top-left-radius: 0px; margin-right: 0px; border-bottom-right-radius: 0px; border-top-right-radius: 0px; }"},
@@ -574,6 +620,17 @@ QMessageBox QPushButton[text="&{_('Yes')}"] {{
               border-radius: 0px;
               height: 48px;
             }
+            .track-resize-handle {
+              background-color: #1B222CFF;
+              border-top: 1px solid #1B222CFF;
+              border-bottom: 1px solid #1B222CFF;
+              border-right: 1px solid #1B222CFF;
+              border-top-right-radius: 0px;
+              border-bottom-right-radius: 0px;
+            }
+            .track-resize-handle:hover {
+              background-color: #333F51FF;
+            }
             .transition {
               height: 48px;
               min-height: 48px;
@@ -646,11 +703,11 @@ QMessageBox QPushButton[text="&{_('Yes')}"] {{
             .playhead-line {
               z-index: 9999;
               position: absolute;
-              height: 316px;
               top: 0;
               width: 2px;
               background-color: #FABE0A;
               margin: -1px;
+              pointer-events: none;
             }
             .point_bezier {
               background-image: url(../themes/cosmic/images/keyframe-bezier.svg);
@@ -661,11 +718,59 @@ QMessageBox QPushButton[text="&{_('Yes')}"] {{
             .point_constant {
               background-image: url(../themes/cosmic/images/keyframe-constant.svg);
             }
+            .track-keyframe-panel-disabled {
+              background-image: url(../themes/cosmic/images/track-keyframe-panel-show-disabled.svg);
+            }
+            .track-keyframe-panel-enabled {
+              background-image: url(../themes/cosmic/images/track-keyframe-panel-show-enabled.svg);
+            }
+            .track-add-above-disabled {
+              background-image: url(../themes/cosmic/images/track-add-above-disabled.svg);
+            }
+            .track-add-above-enabled {
+              background-image: url(../themes/cosmic/images/track-add-above-enabled.svg);
+            }
+            .track-add-below-disabled {
+              background-image: url(../themes/cosmic/images/track-add-below-disabled.svg);
+            }
+            .track-add-below-enabled {
+              background-image: url(../themes/cosmic/images/track-add-below-enabled.svg);
+            }
+            .track-delete-disabled {
+              background-image: url(../themes/cosmic/images/track-delete-disabled.svg);
+            }
+            .track-delete-enabled {
+              background-image: url(../themes/cosmic/images/track-delete-enabled.svg);
+            }
+            .track-locked-disabled {
+              background-image: url(../themes/cosmic/images/track-locked-disabled.svg);
+            }
+            .track-locked-enabled {
+              background-image: url(../themes/cosmic/images/track-locked-enabled.svg);
+            }
+            .track-unlocked-disabled {
+              background-image: url(../themes/cosmic/images/track-unlocked-disabled.svg);
+            }
+            .track-unlocked-enabled {
+              background-image: url(../themes/cosmic/images/track-unlocked-enabled.svg);
+            }
+            .keyframe-panel-add {
+              background-image: url(../themes/cosmic/images/keyframe-panel-add.svg);
+            }
             .marker_icon {
               background-image: url(../themes/cosmic/images/marker.svg);
             }
+            #ruler_label {
+              background: #141923;
+            }
+            #scrolling_ruler {
+              background: #141923;
+            }
         """)
 
+        # Emit signal
+        self.app.window.ThemeChangedSignal.emit(self)
+
     def togglePlayIcon(self, isPlay):
         """ Toggle the play icon from play to pause and back """
         button = self.app.window.videoToolbar.widgetForAction(self.app.window.actionPlay)
