@@ -67,6 +67,9 @@ class Preferences(QDialog):
         # Init UI
         ui_util.init_ui(self)
 
+        # Define the custom category order
+        self.custom_order = ["General", "Preview", "Autosave", "Cache", "Debug", "Keyboard", "Performance", "Location", "Experimental"]
+
         # Get settings
         self.s = get_app().get_settings()
 
@@ -85,8 +88,14 @@ class Preferences(QDialog):
             if "setting" in item and "value" in item:
                 self.params[item["setting"]] = item
 
-        # Connect search textbox
+        # Track widgets and dependencies between settings
+        self.setting_widgets = {}
+        self.dependency_map = {}
+
+        # Connect signals
         self.txtSearch.textChanged.connect(self.txtSearch_changed)
+        self.btnRestoreDefaults.clicked.connect(self.confirm_restore_defaults)
+        self.tabCategories.currentChanged.connect(self.category_tab_changed)
 
         self.requires_restart = False
         self.category_names = {}
@@ -100,9 +109,26 @@ class Preferences(QDialog):
         # Populate preferences
         self.Populate()
 
+        # Highlight invalid keyboard shortcuts
+        self.check_shortcut_validity()
+
         # Restore normal cursor
         get_app().restoreOverrideCursor()
 
+    def category_tab_changed(self, index):
+        """Update the Restore Defaults button label based on the selected tab."""
+        # Get the current widget for the selected tab
+        current_widget = self.tabCategories.widget(index)
+        if not current_widget:
+            return
+
+        # Retrieve the non-translated category using the object name
+        non_translated_category = current_widget.objectName()
+
+        # Update the Restore Defaults button label
+        if non_translated_category:
+            self.btnRestoreDefaults.setText(f"Restore Defaults: {non_translated_category}")
+
     def txtSearch_changed(self):
         """textChanged event handler for search box"""
         log.info("Search for %s", self.txtSearch.text())
@@ -111,13 +137,16 @@ class Preferences(QDialog):
         self.Populate(filter=self.txtSearch.text())
 
     def DeleteAllTabs(self, onlyInVisible=False):
-        """Delete all tabs"""
+        """Delete all tabs and ensure they are fully removed from memory."""
         for name, widget in dict(self.category_tabs).items():
+            # Check visibility condition
             if (onlyInVisible and name not in self.visible_category_names) or not onlyInVisible:
+                # Remove hidden widgets
                 parent_widget = widget.parent().parent()
-                parent_widget.parent().removeWidget(parent_widget)
+                parent_widget.setParent(None)
                 parent_widget.deleteLater()
 
+                # Clean up the references in the internal tracking dictionaries
                 if name in self.category_names:
                     self.category_names.pop(name)
                 if name in self.visible_category_names:
@@ -127,7 +156,6 @@ class Preferences(QDialog):
 
     def Populate(self, filter=""):
         """Populate all preferences and tabs"""
-
         # get translations
         app = get_app()
         _ = app._tr
@@ -137,51 +165,53 @@ class Preferences(QDialog):
 
         self.category_names = {}
         self.category_tabs = {}
-        self.category_sort = {}
         self.visible_category_names = {}
 
-        # Loop through settings and find all unique categories
+        # Reset widget/dependency trackers each time preferences are rebuilt
+        self.setting_widgets = {}
+        self.dependency_map = {}
+
+        # Loop through settings and collect categories
         for item in self.settings_data:
             category = item.get("category")
             setting_type = item.get("type")
-            sort_category = item.get("sort")
-
-            # Indicate sorted category
-            if sort_category:
-                self.category_sort[category] = sort_category
+            sort_type = item.get("sort")
 
             if setting_type != "hidden":
                 # Load setting
                 if category not in self.category_names:
                     self.category_names[category] = []
-
-                    # Create scrollarea
-                    scroll_area = QScrollArea(self)
-                    scroll_area.setWidgetResizable(True)
-                    scroll_area.setVerticalScrollBarPolicy(Qt.ScrollBarAsNeeded)
-                    scroll_area.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
-                    scroll_area.setMinimumSize(675, 100)
-
-                    # Create tab widget and layout
-                    layout = QVBoxLayout()
-                    tabWidget = QWidget(self)
-                    tabWidget.setObjectName("PreferencePanel")
-                    tabWidget.setSizePolicy(QSizePolicy.Preferred, QSizePolicy.Preferred)
-                    tabWidget.setLayout(layout)
-                    scroll_area.setWidget(tabWidget)
-
-                    # Add tab
-                    self.tabCategories.addTab(scroll_area, _(category))
-                    self.category_tabs[category] = tabWidget
-
-                # Append translated title
-                item["title_tr"] = _(item.get("title"))
+                if sort_type:
+                    self.category_sort[category] = sort_type
 
                 # Append settings into correct category
                 self.category_names[category].append(item)
 
-        # Loop through each category setting, and add them to the tabs
-        for category in dict(self.category_tabs).keys():
+        # Create tabs in the predefined order (only add categories present in settings_data)
+        for category in self.custom_order:
+            if category in self.category_names:
+                # Create scroll area
+                scroll_area = QScrollArea(self)
+                scroll_area.setWidgetResizable(True)
+                scroll_area.setVerticalScrollBarPolicy(Qt.ScrollBarAsNeeded)
+                scroll_area.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
+                scroll_area.setMinimumSize(675, 100)
+
+                # Create tab widget and layout
+                layout = QVBoxLayout()
+                tabWidget = QWidget(self)
+                tabWidget.setObjectName("PreferencePanel")
+                tabWidget.setSizePolicy(QSizePolicy.Preferred, QSizePolicy.Preferred)
+                tabWidget.setLayout(layout)
+                scroll_area.setWidget(tabWidget)
+                scroll_area.setObjectName(category)
+
+                # Add tab in the predefined order
+                self.tabCategories.addTab(scroll_area, _(category))
+                self.category_tabs[category] = tabWidget
+
+        # Now populate each tab with settings
+        for category in self.custom_order:
             tabWidget = self.category_tabs[category]
             filterFound = False
 
@@ -189,7 +219,7 @@ class Preferences(QDialog):
             params = self.category_names[category]
             if self.category_sort.get(category):
                 # Sort this category by translated title
-                params.sort(key=operator.itemgetter("title_tr"))
+                params.sort(key=lambda setting: _(setting.get("title")))
 
             # Loop through settings for each category
             for param in params:
@@ -236,6 +266,7 @@ class Preferences(QDialog):
                     # create QLineEdit
                     widget = QLineEdit()
                     widget.setText(_(param["value"]))
+                    widget.setObjectName(param["setting"])
                     widget.textChanged.connect(functools.partial(self.text_value_changed, widget, param))
 
                     if param["type"] == "browse":
@@ -415,6 +446,7 @@ class Preferences(QDialog):
 
                     # Add widget to layout
                     tabWidget.layout().addLayout(layout_hbox)
+                    self.register_setting_widget(param, widget, label)
                 elif (label and filterFound):
                     # Add widget to layout
                     tabWidget.layout().addWidget(label)
@@ -422,9 +454,42 @@ class Preferences(QDialog):
             # Add stretch to bottom of layout
             tabWidget.layout().addStretch()
 
+        self.apply_all_dependencies()
+
         # Delete all tabs and widgets
         self.DeleteAllTabs(onlyInVisible=True)
 
+    def register_setting_widget(self, param, widget, label=None):
+        """Store widget references and register dependency relationships."""
+        setting_name = param.get("setting")
+        if not setting_name or not widget:
+            return
+
+        self.setting_widgets[setting_name] = widget
+        widget.setObjectName(setting_name)
+
+        dependency = param.get("dependency")
+        if dependency:
+            self.dependency_map.setdefault(dependency, []).append((widget, label))
+
+    def apply_all_dependencies(self):
+        """Apply dependency state to all registered widgets."""
+        for setting_name in list(self.dependency_map.keys()):
+            self.apply_dependency_state(setting_name)
+
+    def apply_dependency_state(self, setting_name):
+        """Enable/disable dependent widgets based on controller state."""
+        controlled_widgets = self.dependency_map.get(setting_name, [])
+        if not controlled_widgets:
+            return
+
+        enabled = bool(self.s.get(setting_name))
+        for widget, label in controlled_widgets:
+            if widget:
+                widget.setEnabled(enabled)
+            if label:
+                label.setEnabled(enabled)
+
     def selectExecutable(self, widget, param):
         _ = get_app()._tr
 
@@ -463,6 +528,16 @@ class Preferences(QDialog):
         if "restart" in param and param["restart"]:
             self.requires_restart = True
 
+    def _apply_timeline_thumbnail_style(self):
+        """Push the current thumbnail preference to the QWidget timeline."""
+        timeline_widget = getattr(get_app().window, "timeline", None)
+        if not hasattr(timeline_widget, "set_thumbnail_style"):
+            return
+        try:
+            timeline_widget.set_thumbnail_style(self.s.get("timeline-thumbnail-style"))
+        except Exception:
+            log.warning("Failed to apply timeline thumbnail style live", exc_info=1)
+
     def bool_value_changed(self, widget, param, state):
         # Save setting
         if state == Qt.Checked:
@@ -491,6 +566,10 @@ class Preferences(QDialog):
         # Check for restart
         self.check_for_restart(param)
 
+        # Update any dependent widgets
+        if param.get("setting"):
+            self.apply_dependency_state(param["setting"])
+
     def spinner_value_changed(self, param, value):
         # Save setting
         self.s.set(param["setting"], value)
@@ -532,15 +611,28 @@ class Preferences(QDialog):
         # If this setting is a keyboard mapping, parse it first
         if param.get("category") == "Keyboard":
             previous_value = value
-            value = QKeySequence(value).toString()
-            log.info(
-                "Parsing keyboard mapping via QKeySequence from %s to %s",
-                previous_value, value)
+
+            # Split the input value by the '|' delimiter
+            key_sequences = value.split('|')
+
+            # Parse each sequence part and re-join them with ' | ' after parsing
+            parsed_sequences = [QKeySequence(seq).toString() for seq in key_sequences]
+
+            # Join the parsed sequences back with ' | '
+            value = ' | '.join(parsed_sequences)
+            log.info("Parsing keyboard mapping via QKeySequence from %s to %s", previous_value, value)
 
         # Save setting
         self.s.set(param["setting"], value)
         log.info(value)
 
+        # Reload shortcuts (if needed)
+        if param.get("category") == "Keyboard":
+            get_app().window.initShortcuts()
+
+            # Check for duplicates and update UI feedback
+            self.check_shortcut_validity()
+
         # Check for restart
         self.check_for_restart(param)
 
@@ -566,9 +658,11 @@ class Preferences(QDialog):
 
         if param["setting"] == "theme":
             # Apply selected theme to UI
-            from themes.manager import ThemeManager, ThemeName
-            theme_enum = ThemeName.find_by_name(value)
-            ThemeManager().apply_theme(theme_enum)
+            if get_app().theme_manager:
+                get_app().theme_manager.apply_theme(value)
+
+        if param["setting"] == "timeline-thumbnail-style":
+            self._apply_timeline_thumbnail_style()
 
         # Check for restart
         self.check_for_restart(param)
@@ -670,6 +764,84 @@ class Preferences(QDialog):
 
         return is_supported
 
+    def confirm_restore_defaults(self):
+        """Prompt the user for confirmation before restoring defaults for the current tab."""
+        # Get the current tab index and widget
+        current_index = self.tabCategories.currentIndex()
+        current_widget = self.tabCategories.widget(current_index)
+
+        # Retrieve the non-translated category using the object name
+        category = current_widget.objectName()
+
+        # Prompt the user for confirmation using named placeholders in the translation
+        _ = get_app()._tr
+        reply = QMessageBox.question(
+            self,
+            _('Restore Defaults').format(category=category),
+            _('Restore default values for {category}?').format(category=category),
+            QMessageBox.Yes | QMessageBox.No,
+            QMessageBox.No
+        )
+
+        # If the user confirms, restore the settings for the current category
+        if reply == QMessageBox.Yes:
+            # Restore category settings
+            self.requires_restart = self.s.restore(category_filter=category)
+            self.settings_data = self.s.get_all_settings()
+
+            # Re-apply thumbnail style to the QWidget timeline if it changed
+            self._apply_timeline_thumbnail_style()
+
+            # Repopulate preferences
+            self.Populate()
+            self.tabCategories.setCurrentIndex(current_index)
+
+            # Update shortcuts on main window
+            get_app().window.initShortcuts()
+
+            # Highlight invalid keyboard shortcuts
+            self.check_shortcut_validity()
+
+    def check_shortcut_validity(self):
+        """Check all keyboard settings for duplicate or invalid shortcuts and update the UI."""
+
+        # Set to track all key sequences and prevent duplication
+        used_shortcuts = {}
+
+        # Iterate over all keyboard shortcuts from the application settings
+        for shortcut in get_app().window.getAllKeyboardShortcuts():
+            method_name = shortcut.get('setting')
+
+            # Get list of key sequences (divided by | delimiter)
+            shortcut_sequences = get_app().window.getShortcutByName(method_name)
+
+            # Create QKeySequence list for each sequence
+            key_sequences = [QKeySequence(seq).toString() for seq in shortcut_sequences if seq]
+
+            for key_sequence in key_sequences:
+                if key_sequence in used_shortcuts:
+                    # Mark both current and new shortcut as duplicates
+                    used_shortcuts[key_sequence]['is_duplicate'] = True
+                    used_shortcuts[key_sequence]['params'].append(method_name)
+                else:
+                    used_shortcuts[key_sequence] = {'is_duplicate': False, 'params': [method_name]}
+
+        # Update the UI based on shortcut validation
+        self.update_shortcut_visual_feedback(used_shortcuts)
+
+    def update_shortcut_visual_feedback(self, shortcut_map):
+        """Update the UI to provide feedback for duplicated/invalid shortcuts."""
+
+        for key_sequence, info in shortcut_map.items():
+            for param_name in info['params']:
+                # Find the QLineEdit using the objectName (which is set to the param name)
+                widget = self.findChild(QLineEdit, param_name)
+
+                if widget:
+                    if info['is_duplicate']:
+                        # Mark the field with red text and border for duplicates
+                        widget.setStyleSheet("color: red;")
+
     def closeEvent(self, event):
         """Signal for closing Preferences window"""
         # Invoke the close button
