@@ -45,8 +45,7 @@ class PreviewParent(QObject, UpdateInterface):
         """ This method is invoked by the UpdateManager each time a change happens (i.e UpdateInterface) """
 
         # Ignore changes that don't affect libopenshot
-        if len(action.key) >= 1 and action.key[0].lower() in ["files", "history", "markers", "layers",
-                                                              "scale", "profile", "sample_rate"]:
+        if action and len(action.key) >= 1 and action.key[0].lower() in ["files", "history", "markers", "layers", "scale", "profile", "sample_rate", "export_settings"]:
             return
 
         try:
@@ -308,7 +307,6 @@ class PlayerWorker(QObject):
     def LoadFile(self, path=None):
         """ Load a media file into the video player """
         # Check to see if this path is already loaded
-        # TODO: Determine why path is passed in as an empty string instead of None
         if path == self.clip_path or (not path and not self.clip_path):
             return
 
@@ -361,8 +359,7 @@ class PlayerWorker(QObject):
                 new_clip = openshot.Clip(path)
                 self.clip_reader.AddClip(new_clip)
             except:
-                log.error('Failed to load media file into video player: %s' % path)
-                return
+                log.warning('Failed to load media file into video player: %s' % path)
 
             # Assign new clip_reader
             self.clip_path = path
