@@ -26,13 +26,13 @@
  """
 
 import os
-import copy
 import subprocess
 import sys
 import re
 import functools
 import shlex
 import json
+from time import sleep
 
 # Try to get the security-patched XML functions from defusedxml
 try:
@@ -47,7 +47,7 @@ from PyQt5.QtWidgets import (
     QApplication, QListView, QMessageBox,
     QComboBox, QDoubleSpinBox, QLabel, QPushButton, QLineEdit, QPlainTextEdit,
 )
-from PyQt5.QtGui import QColor, QImage, QPixmap
+from PyQt5.QtGui import QColor, QImage, QPixmap, QIcon
 
 from classes import info
 from classes.logger import log
@@ -63,7 +63,6 @@ class BlenderListView(QListView):
 
     # Our signals
     start_render = pyqtSignal(str, str, int)
-    cancel_render = pyqtSignal()
 
     def currentChanged(self, selected, deselected):
         # Get selected item
@@ -217,6 +216,11 @@ class BlenderListView(QListView):
         self.params[param["name"]] = value
         log.info('Animation param %s set to %s' % (param["name"], value))
         if param["name"] == "length_multiplier":
+            # Convert value to float (and multiply with project FPS diff)
+            # This converts all length_multipliers to the correct project FPS reference.
+            # For example, a 1X multiplier would be 1.2X for a 30 FPS project
+            # using a 25 FPS animated title - to scale up to the correct # of frames.
+            self.params[param["name"]] = float(value) * self.project_fps_diff
             self.init_slider_values()
 
     def color_button_clicked(self, widget, param, index):
@@ -226,7 +230,8 @@ class BlenderListView(QListView):
         color_value = self.params[param["name"]]
         currentColor = QColor("#FFFFFF")
         if len(color_value) >= 3:
-            currentColor.setRgbF(color_value[0], color_value[1], color_value[2])
+            alpha = color_value[3] if len(color_value) >= 4 else 1.0
+            currentColor.setRgbF(color_value[0], color_value[1], color_value[2], alpha)
         # Store our arguments for the callback to pick up again
         self._color_scratchpad = (widget, param)
         ColorPicker(currentColor, callback=self.color_selected, parent=self.win)
@@ -289,7 +294,7 @@ class BlenderListView(QListView):
         """ Init the slider and preview frame label to the currently selected animation """
 
         # Get current preview slider frame
-        length = int(self.params.get("end_frame", 1)) * int(self.params.get("length_multiplier", 1))
+        length = int(self.params.get("end_frame", 1) * self.params.get("length_multiplier", 1.0))
 
         # Update the preview slider
         middle_frame = int(length / 2)
@@ -308,20 +313,24 @@ class BlenderListView(QListView):
             return
 
         # Compose image sequence data
+        filename = "{}%04d.png".format(self.params["file_name"])
         seq_params = {
             "folder_path": os.path.join(info.BLENDER_PATH, self.unique_folder_name),
             "base_name": self.params["file_name"],
             "fixlen": True,
             "digits": 4,
-            "extension": "png"
+            "extension": "png",
+            "fps": {
+                "num": self.fps.get("num", 25),
+                "den": self.fps.get("den", 1)
+            },
+            "pattern": filename,
+            "path": os.path.join(os.path.join(info.BLENDER_PATH, self.unique_folder_name), filename)
         }
-
-        filename = "{}%04d.png".format(seq_params["base_name"])
-        final_path = os.path.join(seq_params["folder_path"], filename)
         log.info('RENDER FINISHED! Adding to project files: {}'.format(filename))
 
         # Add to project files
-        get_app().window.files_model.add_files(final_path, seq_params)
+        get_app().window.files_model.add_files(seq_params.get("path"), seq_params, prevent_recent_folder=True)
 
         # We're done here
         self.win.close()
@@ -362,9 +371,11 @@ class BlenderListView(QListView):
     def update_progress_bar(self, current_frame):
 
         # update label and preview slider
+        was_blocked = self.win.sliderPreview.blockSignals(True)
         self.win.sliderPreview.setValue(current_frame)
+        self.win.sliderPreview.blockSignals(was_blocked)
 
-        length = int(self.params.get("end_frame", 1)) * int(self.params.get("length_multiplier", 1))
+        length = int(self.params.get("end_frame", 1) * self.params.get("length_multiplier", 1.0))
         self.win.lblFrame.setText("{}/{}".format(current_frame, length))
 
     @pyqtSlot(int)
@@ -374,7 +385,7 @@ class BlenderListView(QListView):
             self.preview_timer.start()
 
         # Update preview label
-        length = int(self.params.get("end_frame", 1)) * int(self.params.get("length_multiplier", 1))
+        length = int(self.params.get("end_frame", 1) * self.params.get("length_multiplier", 1.0))
         self.win.lblFrame.setText("{}/{}".format(new_value, length))
 
     def preview_timer_onTimeout(self):
@@ -389,16 +400,15 @@ class BlenderListView(QListView):
     def get_animation_details(self):
         """ Build a dictionary of all animation settings and properties from XML """
 
-        if not self.selected:
-            return {}
-        elif self.selected and self.selected.row() == -1:
+        # Get current selection (if any)
+        current = self.selectionModel().currentIndex()
+        if not current.isValid():
             return {}
 
         # Get all selected rows items
-        ItemRow = self.blender_model.model.itemFromIndex(self.selected).row()
-        animation_title = self.blender_model.model.item(ItemRow, 1).text()
-        xml_path = self.blender_model.model.item(ItemRow, 2).text()
-        service = self.blender_model.model.item(ItemRow, 3).text()
+        animation_title = current.sibling(current.row(), 1).data(Qt.DisplayRole)
+        xml_path = current.sibling(current.row(), 2).data(Qt.DisplayRole)
+        service = current.sibling(current.row(), 3).data(Qt.DisplayRole)
 
         # load xml effect file
         xmldoc = xml.parse(xml_path)
@@ -450,6 +460,9 @@ class BlenderListView(QListView):
     def refresh_view(self):
         self.blender_model.update_model()
 
+        # Sort by column 0
+        self.blender_model.proxy_model.sort(0)
+
     def get_project_params(self, is_preview=True):
         """ Return a dictionary of project related settings, needed by the Blender python script. """
 
@@ -535,7 +548,7 @@ Blender Path: {}
         # prepare string to inject
         user_params = "\n#BEGIN INJECTING PARAMS\n"
 
-        param_data = copy.deepcopy(self.params)
+        param_data = json.loads(json.dumps(self.params))
         param_data.update(self.get_project_params(is_preview))
 
         param_serialization = json.dumps(param_data)
@@ -564,6 +577,15 @@ Blender Path: {}
         with open(source_path, 'r') as f:
             script_body = f.read()
 
+        # Prepend shared helper library to every script (keeps templates lightweight)
+        base_path = os.path.join(info.PATH, "blender", "scripts", "base.py.in")
+        try:
+            with open(base_path, 'r') as f:
+                base_body = f.read()
+            script_body = base_body + "\n\n" + script_body
+        except IOError:
+            log.error("Could not load base Blender helper script at %s", base_path)
+
         # insert our modifications to script source
         script_body = script_body.replace("# INJECT_PARAMS_HERE", user_params)
 
@@ -576,20 +598,16 @@ Blender Path: {}
 
     @pyqtSlot(str)
     def update_image(self, image_path):
-
-        # get the pixbuf
-        image = QImage(image_path)
-        scaled_image = image.scaled(
-            self.win.imgPreview.size(),
-            Qt.KeepAspectRatio,
-            Qt.SmoothTransformation)
-        pixmap = QPixmap.fromImage(scaled_image)
-        self.win.imgPreview.setPixmap(pixmap)
+        # Scale preview for high DPI display (if any)
+        scale = get_app().devicePixelRatio()
+        display_pixmap = QIcon(image_path).pixmap(self.win.imgPreview.size())
+        display_pixmap.setDevicePixelRatio(scale)
+        self.win.imgPreview.setPixmap(display_pixmap)
 
     def Cancel(self):
         """Cancel the current render, if any"""
-        #QMetaObject.invokeMethod(self.worker, 'Cancel', Qt.DirectConnection)
-        self.cancel_render.emit()
+        if "worker" in dir(self):
+            self.worker.Cancel()
 
     def Render(self, frame=None):
         """ Render an images sequence of the current template using Blender 2.62+ and the
@@ -619,7 +637,6 @@ Blender Path: {}
         self.background.started.connect(self.worker.Render)
 
         self.worker.render_complete.connect(self.render_finished)
-        self.cancel_render.connect(self.worker.Cancel)
 
         # State changes
         self.worker.end_processing.connect(self.end_processing)
@@ -645,7 +662,7 @@ Blender Path: {}
         self.inject_params(source_script, target_script, frame)
 
         # Note whether we're rendering a preview or an animation
-        self.final_render = bool(frame is None)
+        self.final_render = frame is None
 
         # Run worker in background thread
         self.background.start()
@@ -672,6 +689,15 @@ Blender Path: {}
         self.preview_timer.setSingleShot(True)
         self.preview_timer.timeout.connect(self.preview_timer_onTimeout)
 
+        # Calculate diff between project FPS and title FPS
+        # All animated titles are created at an assumed default 25.0 FPS
+        self.fps = self.app.project.get("fps")
+        fps_float = self.fps["num"] / float(self.fps["den"])
+
+        # NOTE: Blender can only use INT precision when remapping
+        # frames. 1X, 2X, 3X, etc...  not 1.2X
+        self.project_fps_diff = round(fps_float / 25.0)
+
         # Init dictionary which holds the values to the template parameters
         self.params = {}
 
@@ -682,9 +708,9 @@ Blender Path: {}
         self.processing_mode(cursor=False)
 
         # Setup header columns
-        self.setModel(self.blender_model.model)
-        self.setIconSize(QSize(131, 108))
-        self.setGridSize(QSize(102, 92))
+        self.setModel(self.blender_model.proxy_model)
+        self.setIconSize(info.LIST_ICON_SIZE)
+        self.setGridSize(info.LIST_GRID_SIZE)
         self.setViewMode(QListView.IconMode)
         self.setResizeMode(QListView.Adjust)
         self.setUniformItemSizes(True)
@@ -728,8 +754,9 @@ class Worker(QObject):
 
         # Init regex expression used to determine blender's render progress
         self.blender_version_re = re.compile(
-            r"^Blender ([0-9a-z\.]*)", flags=re.MULTILINE)
+            r"Blender ([0-9a-z\.]*)", flags=re.MULTILINE)
         self.blender_frame_re = re.compile(r"Fra:([0-9,]+)")
+        self.blender_frame_alt_re = re.compile(r"[Ff]rame[s]?[^\d]*([0-9]+)")
         self.blender_saved_re = re.compile(r"Saved: '(.*\.png)")
         self.blender_syncing_re = re.compile(
             r"\| Syncing (.*)$", flags=re.MULTILINE)
@@ -740,19 +767,26 @@ class Worker(QObject):
         self.process = None
         self.canceled = False
 
+        # Get environment variables needed for launching a process without trying to load libraries
+        # from our frozen app bundle
+        self.env = dict(os.environ)
+        if sys.platform == "linux":
+            self.env.pop('LD_LIBRARY_PATH', None)
+            log.debug('Removing custom LD_LIBRARY_PATH from environment variables when launching Blender')
+
         self.startupinfo = None
         if sys.platform == 'win32':
             self.startupinfo = subprocess.STARTUPINFO()
             self.startupinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
 
-    @pyqtSlot()
     def Cancel(self):
         """Cancel worker render"""
         if self.process:
-            # Stop blender process if running
-            self.process.terminate()
+            while self.process and self.process.poll() == None:
+                log.debug("Terminating Blender Process")
+                self.process.terminate()
+                sleep(0.1)
         self.canceled = True
-        self.finished.emit()
 
     def blender_version_check(self):
         # Check the version of Blender
@@ -770,14 +804,19 @@ class Worker(QObject):
             self.process = subprocess.Popen(
                 command_get_version,
                 stdout=subprocess.PIPE, stderr=subprocess.STDOUT,
-                startupinfo=self.startupinfo,
+                startupinfo=self.startupinfo, env=self.env, cwd=info.HOME_PATH
             )
             # Give Blender up to 10 seconds to respond
             (out, err) = self.process.communicate(timeout=10)
         except subprocess.TimeoutExpired:
+            log.error("Blender version check timed out")
             self.process.kill()
             self.blender_error_nodata.emit()
             return False
+        except FileNotFoundError:
+            log.error("Blender executable not found at path: %s", self.blender_exec_path)
+            self.blender_error_nodata.emit()
+            return False
         except Exception:
             # Error running command.  Most likely the blender executable path in
             # the settings is incorrect, or is not a supported Blender version
@@ -785,7 +824,7 @@ class Worker(QObject):
             self.blender_error_nodata.emit()
             return False
 
-        ver_string = out.decode('utf-8')
+        ver_string = out.decode('utf-8', errors='ignore')
         log.debug("Blender output:\n%s", ver_string)
 
         ver_match = self.blender_version_re.search(ver_string)
@@ -818,6 +857,16 @@ class Worker(QObject):
             self.current_frame = int(output_frame.group(1))
             # update progress on frame change
             self.progress.emit(self.current_frame)
+        else:
+            alt_frame = self.blender_frame_alt_re.search(line)
+            if alt_frame:
+                try:
+                    new_frame = int(alt_frame.group(1))
+                    if new_frame != self.current_frame:
+                        self.current_frame = new_frame
+                        self.progress.emit(self.current_frame)
+                except ValueError:
+                    pass
 
         output_syncing = self.blender_syncing_re.search(line)
         if output_syncing:
@@ -832,8 +881,23 @@ class Worker(QObject):
 
         output_saved = self.blender_saved_re.search(line)
         if output_saved:
+            # Try to infer frame number from the saved filename (Blender 5 logs)
+            saved_path = output_saved.group(1)
+            base_name = os.path.splitext(os.path.basename(saved_path))[0]
+            if self.preview_frame > 0:
+                self.current_frame = self.preview_frame
+            else:
+                frame_from_name = re.search(r"([0-9]{1,5})$", base_name)
+                if frame_from_name:
+                    try:
+                        guessed_frame = int(frame_from_name.group(1))
+                        self.current_frame = guessed_frame
+                    except ValueError:
+                        pass
             self.frame_count += 1
             log.debug("Saved frame %d", self.current_frame)
+            # Emit progress on save to update UI even if render lines were missed
+            self.progress.emit(self.current_frame)
             self.frame_saved.emit(self.current_frame)
             # Update preview image
             self.image_updated.emit(output_saved.group(1))
@@ -880,7 +944,7 @@ class Worker(QObject):
             self.process = subprocess.Popen(
                 command_render, bufsize=512,
                 stdout=subprocess.PIPE, stderr=subprocess.STDOUT,
-                startupinfo=self.startupinfo,
+                startupinfo=self.startupinfo, env=self.env, cwd=info.HOME_PATH
             )
             # Signal UI that background task is running
             self.start_processing.emit()
@@ -902,8 +966,6 @@ class Worker(QObject):
             self.end_processing.emit()
             log.info("Blender process exited, %d frames saved.", self.frame_count)
 
-            if self.canceled:
-                return
             if self.frame_count < 1:
                 log.warning("No frame detected from Blender!")
                 log.warning("Blender output:\n{}".format(
